---
name: Implementation Improvement
about: Suggest a better implementation for Flask-Jeroboam
---

## Implementation Improvement: <NAME>

### Abstract

<!--
Replace this comment with a A brief summary of the improvement.
Exemple: Response Model as Lists of primitives or BaseModels
-->

#### Motivation

<!--
Replace this comment with why this improvement is important, and how it will benefit the project.
Identify the problem it solves or the opportunity it generates.
Exemple: When users want to return a list of objects without any metadata like the total_count, it's the most
straightforward approach to defining a response_model and make the economy of defining a wrapping response_model.
-->

#### Current Implementation

<!--

-->

#### Desired Implementation

<!--

-->

#### Expected Benefit

<!--

-->

### Alternatives Considered

<!--
Replace this comment with a clear and concise description of any alternative solutions or features that were considered.
Explain why the proposed solution is the best approach.
-->

### Additional context

<!--
Replace this comment with any other relevant information, that may be helpful in understanding the feature request.
-->
